Subject: [PATCH 30/92] gnu: python-dateutil: Move to pyproject-build-system.

From: Nicolas Graves <[email-masked]>
Date: Fri, 10 May 2024 00:53:25 +0200

* gnu/packages/time.scm (python-dateutil): Improve package style.
  [build-system]: Move to pyproject-build-system.
  [arguments]: Use <#:test-flags> instead of check phase replacement.

Change-Id: I252fbe47f04ba6a2fbcc497565cbf6e352f9d06c
---
 gnu/packages/time.scm | 23 ++++++++---------------
 1 file changed, 8 insertions(+), 15 deletions(-)

diff --git a/gnu/packages/time.scm b/gnu/packages/time.scm
index 96fe9f561a0..552ac346c4a 100644
--- a/gnu/packages/time.scm
+++ b/gnu/packages/time.scm
@@ -242,22 +242,15 @@ (define-public python-dateutil
        (uri (pypi-uri "python-dateutil" version))
        (patches (search-patches "python-dateutil-pytest-compat.patch"))
        (sha256
-        (base32
-         "11iy7m4bp2lgfkcl0r6xzf34bvk7ppjmsyn2ygfikbi72v6cl8q1"))))
-    (build-system python-build-system)
+        (base32 "11iy7m4bp2lgfkcl0r6xzf34bvk7ppjmsyn2ygfikbi72v6cl8q1"))))
+    (build-system pyproject-build-system)
     (arguments
-     `(#:phases (modify-phases %standard-phases
-                  (replace 'check
-                    (lambda _
-                      ;; Delete tests that depend on "freezegun" to avoid a
-                      ;; circular dependency.
-                      (delete-file "dateutil/test/test_utils.py")
-                      (delete-file "dateutil/test/test_rrule.py")
-
-                      ;; XXX: Fails to get timezone from /etc/localtime.
-                      (delete-file "dateutil/test/test_tz.py")
-
-                      (invoke "pytest" "-vv"))))))
+     (list
+      #:test-flags '(list  ; avoid freezegun dependency
+                     "--ignore=dateutil/test/test_utils.py"
+                     "--ignore=dateutil/test/test_rrule.py"
+                     ;; XXX: Fails to get timezone from /etc/localtime.
+                     "--ignore=dateutil/test/test_tz.py")))
     (native-inputs
      (list python-pytest python-pytest-cov python-setuptools-scm))
     (propagated-inputs
-- 
2.41.0